#install.packages("tidyverse")
library(tidyverse)


#----------------
# Allergy data
#----------------

n_male=c(74,79,79,74,73)
n_female=c(42,37,34,33,37)

mean_male=c(5.09,4.84,4.81,4.86,4.79)
mean_female=c(5.26,5.42,5.26,5.61,5.35)

sd_male=c(1.59,1.62,1.54,1.62,1.68)
sd_female=c(1.65,1.69,1.69,1.58,1.83)

md=mean_male-mean_female
s2={(n_male-1)*sd_male^{2}+(n_female-1)*sd_female^{2}}/(n_male+n_female-2)
SE=sqrt(s2*(1/n_male+1/n_female))

sig=SE
year=c(2015,2016,2018,2019,2022)
x0=c(1,2,3,4,5)
plot(sig^2,xlab="i (index)",ylab="Variance")
fit=lm(log(sig^2)~log(x0))
C=exp(fit$coef[1])
A=fit$coef[2]
I=seq(0,max(x0),length=1000)
summary(fit)

ggplot()+
  geom_point(aes(x=x0, y=sig^2))+
  geom_line(aes(x=I, y=C*I^A),color="blue")+
  geom_text(aes(x = x0, y = sig^2,label=year),hjust=0,
            nudge_y=-0.008,nudge_x = -0.2,size=3)+
  
  labs(x="i (index)",y="Variance")+
  annotate("text",x=3.3,y=0.04,label="Fitted model (R-squared = 0.87)",size=5,color="blue")+
  annotate("text",x=3.1,y=0.03,label=expression(sigma^2 == 0.0964 %*% i^0.13),size=5,color="blue")+
  annotate("text",x=3.2,y=0.02,label=expression(paste(alpha == 0.13, ": consistent")),size=5,color="blue")


#----------------
# Diabetes data
#----------------


MD=c(-0.70,-0.47,-0.20,-0.40,-0.10,-0.33,-0.01,-0.20)
Low=c(-0.75,-0.71,-0.36,-0.75,-0.25,-0.51,-0.18,-0.52)
Up=c(-0.65,-0.23,-0.04,-0.05,0.05,-0.15,0.16,0.12)
options(scipen=100)


Y=MD
SE=(Up-Low)/2/1.96
n=length(Y)
sig=sort(SE)
plot(sig^2,xlab="i (index)",ylab="Variance")
fit=lm(log(sig^2)~log(c(1:n)))
C=exp(fit$coef[1])
A=fit$coef[2]
I=seq(0,n,length=1000)
summary(fit)

ggplot()+
  geom_point(aes(x=c(1:n), y=sig^2))+
  geom_line(aes(x=I, y=C*I^A),color="blue")+
  labs(x="i (index)",y="Variance")+
  annotate("text",x=1.8,y=0.031,label="Fitted model (R-squared = 0.91)",size=5,color="blue")+
  annotate("text",x=1.2,y=0.029,label=expression(sigma^2 == 0.0009 %*% i^1.63),size=5,color="blue")+
  annotate("text",x=1.5,y=0.027,label=expression(paste(alpha == 1.63, ": inconsistent")),size=5,color="blue")



#----------------
# COVID-19 data
#----------------

N=c(440,127,102,123,274,200,1591,102,403,27,191)
RR=c(1.99,1.81,3.24,1.71,1.97,1.80,1.59,1.69,3.43,18.00,3.12)
Low=c(0.53,1.05,1.86,1.05,1.41,0.94,1.32,0.89,2.56,1.10,2.07)
Up=c(7.42,3.09,5.62,2.79,2.76,3.43,1.92,3.21,4.59,294.88,4.71)
Male=c(56.4,63,52,49,62,49.5,82,58,47.9,45,62)

Y=log(RR)
SE=(log(Up)-log(Low))/2/1.96
n=length(Y)
sig=rev(sort(SE))
plot(sig^2,xlab="i (index)",ylab="Variance")
fit=lm(log(sig^2)~log(c(1:n)))
C=exp(fit$coef[1])
A=fit$coef[2]
I=seq(0,n,length=1000)
points(I,C*I^A,type="s",col="blue")
summary(fit)
legend("center",legend="Fitted model (R-squared = 0.94)",
       col="blue",lty=1,text.col="blue",bty="n")
text(x=5.2,y=0.9, col="blue",
     expression(sigma^2 == 1.69 %*% i^-1.91))
text(x=6,y=0.75, col="blue",
     expression(paste(alpha == -1.91, ": inconsistent")))



ggplot()+
  geom_point(aes(x=c(1:n), y=sig^2))+
  geom_line(aes(x=I, y=C*I^A),color="blue")+
  labs(x="i (index)",y="Variance")+
  scale_x_continuous(limits = c(0,11.5))+
  scale_y_continuous(limits = c(0,2.3))+
  annotate("text",x=6.3,y=1.5,label="Fitted model (R-squared = 0.94)",size=5,color="blue")+
  annotate("text",x=5.2,y=1.35,label=expression(sigma^2 == 1.69 %*% i^-1.91),size=5,color="blue")+
  annotate("text",x=5.6,y=1.2,label=expression(paste(alpha == -1.91, ": consistent")),size=5,color="blue")

